#####################
Citing & Contributing
#####################

If you use Moran [Py]cess in your research **please cite the following
article** in your paper:

   Bak & Rozlach, (2020). Moran Pycess: a Python package to simulate Moran processes driven by game theory. Journal of Open Source Software, 5(54), 2643, https://doi.org/10.21105/joss.02643

Check out our `preliminary results`_ (published in the Journal of Brief Ideas) too!

This project lives off your contributions, be it in the form of bug reports,
feature requests, discussions, or fixes and other code changes. Please refer
to the `contributing guidelines`_ if you are interested to
contribute. Please mind the `code of conduct`_ for all
interactions with the community.

For questions or suggestions regarding the code, please use the `issue tracker`_ at GitHub.

.. _preliminary results: https://beta.briefideas.org/ideas/d292ad28e6818d20aad2286e1c9b6aa2
.. _contributing guidelines: https://github.com/AngryMaciek/angry-moran-simulator/blob/master/CONTRIBUTING.md
.. _code of conduct: https://github.com/AngryMaciek/angry-moran-simulator/blob/master/CODE_OF_CONDUCT.md
.. _issue tracker: https://github.com/AngryMaciek/angry-moran-simulator/issues
